==> bacula-docs-2.4.2.tar.bz2: bacula-docs-2.4.2/home-page/de/pages/fsfe.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
   <td class="contentTopic">
   Die Free Software Foundation Europe Lizenz
   </td>
   </tr>

   
   <tr>
     <td class="content">
   Das Bacula-Projekt hat das Urheberrecht in einem treuh&auml;ndischen
   Verh&auml;ltnis an den Free Software Foundation Europe e.V. &uuml;bertragen.
   Das erlaubt der FSFE Bacula vor Missbrauch zu sch&uuml;tzen, w&auml;hrend
   das Projekt, ohne verwaltungstechnische Belastungen durch Pflege der
   Urheberechtsdokumente, arbeiten kann.
   <p>
   Falls Sie mehr als nur ein paar Zeilen zum Bacula-Quelltext oder zur Dokumentation
   beitragen wollen, fordern wir Sie auf, das treuh&auml;ndische Lizenzabkommen
   f&uuml;r Entwickler (Link siehe unten) auszuf&uuml;llen.
   Das ist dasselbe Abkommen, dass sowohl ich (Kern), als auch die anderen Entwickler
   unterschrieben haben um die Urheberechte an die FSFE zu &uuml;bertragen.
   <p>
   Das Ausf&uuml;llen ist ziemlich einfach. Bitte machen Sie zwei Kopien und tragen Sie
   Ihren Namen und E-Mail-Adresse, sowie das Datum, auf der ersten Seite ein. 
   <p>
   Auf der dritten Seite, hinter &quot;the author&quot;, tragen Sie Ihren Namen
   und die anderen erforderlichen Informationen ein. Dies dient nur dazu,
   Sie eindeutig zu identifizieren.
   <p>
   Falls Sie in einem Angestelltenverh&auml;ltnis besch&auml;ftigt sind und w&auml;hrend Ihrer
   Arbeitszeit an Bacula arbeiten, hat oftmals Ihr Arbeitgeber die Rechte an dem was Sie
   programmieren oder dokumentieren. In diesem Fall tragen Sie hier die entsprechenden
   Informationen Ihres Arbeitgebers ein.
   <p>
   Auf der vierten Seite k&ouml;nnen Sie einfach &quot;All code and documentation
   contributed to the Bacula.org project&quot; eintragen. Falls Sie noch genauere Angaben
   machen m&ouml;chten, steht Ihnen das selbstverst&auml;ndlich frei.
   <p>
   Danke, dass Sie sich die Zeit genommen haben, das Lizenzabkommen auzuf&uuml;llen und abzuschicken.   
   <p>
   <ul>
   <li> <a href="FLA-bacula.en.pdf" >treuh&auml;ndisches Lizenzabkommen als PDF</a> (eng.)
    </li>
   </ul>
   </td>
   <td class="content">
   <ul>
   </ul>
   </td>
   </tr>
   
</table>
 <p>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-5.0.2.tar.bz2: bacula-docs-5.0.2/home-page/de/pages/fsfe.php <==
<? require_once("inc/header.php"); ?>
<table>
  <tr>
   <td class="contentTopic">
   Die Free Software Foundation Europe Lizenz
   </td>
   </tr>

   
   <tr>
     <td class="content">
   Das Bacula-Projekt hat das Urheberrecht in einem treuh&auml;ndischen
   Verh&auml;ltnis an den Free Software Foundation Europe e.V. &uuml;bertragen.
   Das erlaubt der FSFE Bacula vor Missbrauch zu sch&uuml;tzen, w&auml;hrend
   das Projekt, ohne verwaltungstechnische Belastungen durch Pflege der
   Urheberechtsdokumente, arbeiten kann.
   <p>
   Falls Sie mehr als nur ein paar Zeilen zum Bacula-Quelltext oder zur Dokumentation
   beitragen wollen, fordern wir Sie auf, das treuh&auml;ndische Lizenzabkommen
   f&uuml;r Entwickler (Link siehe unten) auszuf&uuml;llen.
   Das ist dasselbe Abkommen, dass sowohl ich (Kern), als auch die anderen Entwickler
   unterschrieben haben um die Urheberechte an die FSFE zu &uuml;bertragen.
   <p>
   Das Ausf&uuml;llen ist ziemlich einfach. Bitte machen Sie zwei Kopien und tragen Sie
   Ihren Namen und E-Mail-Adresse, sowie das Datum, auf der ersten Seite ein. 
   <p>
   Auf der dritten Seite, hinter &quot;the author&quot;, tragen Sie Ihren Namen
   und die anderen erforderlichen Informationen ein. Dies dient nur dazu,
   Sie eindeutig zu identifizieren.
   <p>
   Falls Sie in einem Angestelltenverh&auml;ltnis besch&auml;ftigt sind und w&auml;hrend Ihrer
   Arbeitszeit an Bacula arbeiten, hat oftmals Ihr Arbeitgeber die Rechte an dem was Sie
   programmieren oder dokumentieren. In diesem Fall tragen Sie hier die entsprechenden
   Informationen Ihres Arbeitgebers ein.
   <p>
   Auf der vierten Seite k&ouml;nnen Sie einfach &quot;All code and documentation
   contributed to the Bacula.org project&quot; eintragen. Falls Sie noch genauere Angaben
   machen m&ouml;chten, steht Ihnen das selbstverst&auml;ndlich frei.
   <p>
   Abschlie&szlig;end senden Sie die beiden ausgef&uuml;llten Kopien der Lizenz an:<br><p>
   Kern Sibbald<br>
   Cotes-de-Montmoiret 9<br>
   1012 Lausanne<br>
   Switzerland<br>
   <p>
   ich werde sie dann zur Kenntnis nehmen und sie an die Free Software Foundation Europe
   weiterleiten.
   <p>
   Danke, dass Sie sich die Zeit genommen haben, das Lizenzabkommen auszuf&uuml;llen und abzuschicken.   
   <p>
   <ul>
   <li> <a href="FLA-bacula.en.pdf" >treuh&auml;ndisches Lizenzabkommen als PDF</a> (eng.)
    </li>
   </ul>
   </td>
   <td class="content">
   <ul>
   </ul>
   </td>
   </tr>
   
</table>
 <p>
<? require_once("inc/footer.php"); ?>
